@@ -1,6 +1,6 @@
 ##++
-##     CGI Lite v2.04_01
-##     Last modified: 06 Oct 2014 (see CHANGES)
+##     CGI Lite v2.04_02
+##     Last modified: 07 Oct 2014 (see CHANGES)
 ##
 ##     Copyright (c) 1995, 1996, 1997 by Shishir Gundavaram
 ##     All Rights Reserved
@@ -513,7 +513,7 @@ require Exporter;
 ## Global Variables
 ##--
 
-$CGI::Lite::VERSION = '2.04_01';
+$CGI::Lite::VERSION = '2.04_02';
 
 ##++
 ##  Start
@@ -1159,9 +1159,13 @@ sub _store
 
     if ($file) {
 	if ($convert) {
-	    $$info =~ s/\015\012/$eol/og  if ($platform ne 'PC');
-	    $$info =~ s/\015/$eol/og      if ($platform ne 'Mac');
-	    $$info =~ s/\012/$eol/og      if ($platform ne 'Unix');
+		if ($platform eq 'PC') {
+			$$info =~ s/\015(?=[^\012])|[^\015]\K\012/$eol/og;
+		} else {
+	    	$$info =~ s/\015\012/$eol/og;
+	    	$$info =~ s/\015/$eol/og      if ($platform ne 'Mac');
+	    	$$info =~ s/\012/$eol/og      if ($platform ne 'Unix');
+		}
 	} else {
 		binmode $handle;
 	}
